@@ -1,7 +1,7 @@
 /*
-* libslack - http://libslack.org/
+* libslack - https://libslack.org
 *
-* Copyright (C) 1999-2002, 2004, 2010, 2020-2021 raf <raf@raf.org>
+* Copyright (C) 1999-2002, 2004, 2010, 2020-2023 raf <raf@raf.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 *
-* 20210220 raf <raf@raf.org>
+* 20230330 raf <raf@raf.org>
 */
 
 /*
@@ -1117,7 +1117,7 @@ I<locker(3)>
 
 =head1 AUTHOR
 
-20210220 raf <raf@raf.org>
+20230330 raf <raf@raf.org>
 
 =cut
 
@@ -1636,12 +1636,20 @@ int main(int ac, char **av)
 					++errors, printf("Test65: pool_destroy_secure(32) failed: memory not cleared\n");
 				else
 				{
-					++errors, printf("Test65: pool_destroy_secure(32) failed: memory not cleared (possibly - or maybe the already-deallocated memory has just been reused by now)\n");
+					int i, num_nuls = 0;
+
+					for (i = 0; i < 32; i++)
+						if (((unsigned char *)whitebox)[i] == '\0')
+							++num_nuls;
+
+					if (num_nuls < 32 - 8)
 					{
-						int i;
+						++errors, printf("Test65: pool_destroy_secure(32) failed: memory not cleared (possibly - or maybe the already-deallocated memory has just been reused by now)\n");
 						printf("content = \"");
+
 						for (i = 0; i < 32; i++)
 							printf("\\x%02x", ((unsigned char *)whitebox)[i]);
+
 						printf("\" (should be all or mostly \\x00)\n");
 					}
 				}
