@@ -1,5 +1,5 @@
 /*
-* libslack - http://libslack.org/
+* libslack - https://libslack.org
 *
 * Copyright (C) 1999-2002, 2004, 2010, 2020-2023 raf <raf@raf.org>
 *
@@ -16,7 +16,7 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <https://www.gnu.org/licenses/>.
 *
-* 20230313 raf <raf@raf.org>
+* 20230330 raf <raf@raf.org>
 */
 
 /*
@@ -2557,10 +2557,10 @@ The following program:
      prog_set_syntax("[options] arg...");
      prog_set_options(options);
      prog_set_version("1.0");
-     prog_set_date("20230313");
+     prog_set_date("20230330");
      prog_set_author("raf <raf@raf.org>");
      prog_set_contact(prog_author());
-     prog_set_url("http://libslack.org/");
+     prog_set_url("https://libslack.org");
      prog_set_legal("This software is released under the terms of the GPL.\n");
      prog_set_desc("This program is an example of the prog module.\n");
 
@@ -2595,9 +2595,9 @@ will behave like:
 
  Name: example
  Version: 1.0
- Date: 20230313
+ Date: 20230330
  Author: raf <raf@raf.org>
- URL: http://libslack.org/
+ URL: https://libslack.org
 
  This software is released under the terms of the GPL.
 
@@ -2637,7 +2637,7 @@ I<locker(3)>
 
 =head1 AUTHOR
 
-20230313 raf <raf@raf.org>
+20230330 raf <raf@raf.org>
 
 =cut
 
@@ -2781,10 +2781,10 @@ int main(int ac, char **av)
 			"\n"
 			"Name: %s\n"
 			"Version: 1.0\n"
-			"Date: 20230313\n"
+			"Date: 20230330\n"
 			"Author: raf <raf@raf.org>\n"
 			"Vendor: A Software Vendor\n"
-			"URL: http://libslack.org/test/\n"
+			"URL: https://libslack.org/test\n"
 			"\n"
 			"This software is released under the terms of the GPL.\n"
 			"\n"
@@ -2874,11 +2874,11 @@ int main(int ac, char **av)
 	prog_set_syntax("[options]");
 	prog_set_options(prog_options_table);
 	prog_set_version("1.0");
-	prog_set_date("20230313");
+	prog_set_date("20230330");
 	prog_set_author("raf <raf@raf.org>");
 	prog_set_contact("raf <raf@raf.org>");
 	prog_set_vendor("A Software Vendor");
-	prog_set_url("http://libslack.org/test/");
+	prog_set_url("https://libslack.org/test");
 	prog_set_legal("This software is released under the terms of the GPL.\n");
 	prog_set_desc("This program tests the prog module.\n");
 
